@@ -22,9 +22,11 @@ import warnings
 from tempfile import NamedTemporaryFile
 from textwrap import wrap
 
+from datalad import __version__
 from ..cmd import WitlessRunner as Runner
 from ..interface.common_opts import eval_defaults
 from ..log import is_interactive
+from datalad.support.exceptions import CapturedException
 from ..ui.utils import get_console_width
 from ..utils import (
     ensure_unicode,
@@ -32,8 +34,6 @@ from ..utils import (
     unlink,
     get_suggestions_msg,
 )
-from ..version import __version__, __full_version__
-from ..dochelpers import exc_str
 
 from appdirs import AppDirs
 from os.path import join as opj
@@ -77,7 +77,8 @@ class HelpAction(argparse.Action):
                     shell=True)
                 sys.exit(0)
             except (subprocess.CalledProcessError, IOError, OSError, IndexError, ValueError) as e:
-                lgr.debug("Did not use manpage since %s", exc_str(e))
+                ce = CapturedException(e)
+                lgr.debug("Did not use manpage since %s", ce)
         if option_string == '-h':
             usage = parser.format_usage()
             ucomps = re.match(
@@ -116,7 +117,8 @@ class HelpAction(argparse.Action):
         else:
             opt_args_str = "*Options*"
             pos_args_str = "*Arguments*"
-        helpstr = re.sub(r'optional arguments:', opt_args_str, helpstr)
+        # in python 3.10 it switched from "optional arguments" to "options"
+        helpstr = re.sub(r'(optional arguments|options):', opt_args_str, helpstr)
         helpstr = re.sub(r'positional arguments:', pos_args_str, helpstr)
         # usage is on the same line
         helpstr = re.sub(r'^usage:', 'Usage:', helpstr)
@@ -442,9 +444,10 @@ def _maybe_get_single_subparser(cmdlineargs, parser, interface_groups,
                 msg="too few arguments, run with --help or visit https://handbook.datalad.org",
                 exit_code=2)
         lgr.debug("Command line args 1st pass for DataLad %s. Parsed: %s Unparsed: %s",
-                  __full_version__, parsed_args, unparsed_args)
+                  __version__, parsed_args, unparsed_args)
     except Exception as exc:
-        lgr.debug("Early parsing failed with %s", exc_str(exc))
+        ce = CapturedException(exc)
+        lgr.debug("Early parsing failed with %s", ce)
         need_single_subparser = False
         unparsed_args = cmdlineargs[1:]  # referenced before assignment otherwise
     # First unparsed could be either unknown option to top level "datalad"
@@ -568,7 +571,8 @@ def add_entrypoints_to_interface_groups(interface_groups):
             interface_groups.append((ep.name, spec[0], spec[1]))
             lgr.debug('Loaded entrypoint %s', ep.name)
         except Exception as e:
-            lgr.warning('Failed to load entrypoint %s: %s', ep.name, exc_str(e))
+            ce = CapturedException(ce)
+            lgr.warning('Failed to load entrypoint %s: %s', ep.name, ce)
             continue
 
 
