@@ -10,47 +10,45 @@
 
 import os
 import re
-import sys
 from io import StringIO
 from unittest.mock import patch
 
 import datalad
-from ..main import (
-    main,
-    fail_with_short_help,
-    _fix_datalad_ri,
-)
 from datalad import __version__
-from datalad.cmd import (
-    WitlessRunner as Runner,
-    StdOutErrCapture,
+from datalad.api import (
+    Dataset,
+    create,
+)
+from datalad.cmd import StdOutErrCapture
+from datalad.cmd import WitlessRunner as Runner
+from datalad.support.exceptions import CommandError
+from datalad.tests.utils import (
+    SkipTest,
+    assert_equal,
+    assert_in,
+    assert_not_in,
+    assert_raises,
+    assert_re_in,
+    eq_,
+    in_,
+    ok_startswith,
+    on_windows,
+    slow,
+    with_tempfile,
 )
 from datalad.ui.utils import (
     get_console_width,
     get_terminal_size,
 )
-from datalad.api import (
-    create,
-    Dataset,
-)
 from datalad.utils import (
-    chpwd,
     Path,
+    chpwd,
 )
-from datalad.tests.utils import (
-    on_windows,
-    with_tempfile,
-    assert_equal,
-    assert_raises,
-    in_,
-    ok_startswith,
-    assert_in,
-    assert_re_in,
-    assert_not_in,
-    slow,
-    SkipTest,
+
+from ..helpers import fail_with_short_help
+from ..main import (
+    main,
 )
-from datalad.support.exceptions import CommandError
 
 
 def run_main(args, exit_code=0, expect_stderr=False):
@@ -90,16 +88,23 @@ def run_main(args, exit_code=0, expect_stderr=False):
 
 # TODO: switch to stdout for --version output
 def test_version():
+    # we just get a version if not asking for a version of some command
     stdout, stderr = run_main(['--version'], expect_stderr=True)
+    eq_(stdout.rstrip(), "datalad %s" % datalad.__version__)
 
-    # and output should contain our version, copyright, license
-
-    # https://hg.python.org/cpython/file/default/Doc/whatsnew/3.4.rst#l1952
-    out = stdout if sys.version_info >= (3, 4) else stderr
-    ok_startswith(out, 'datalad %s\n' % datalad.__version__)
+    stdout, stderr = run_main(['clone', '--version'], expect_stderr=True)
+    ok_startswith(stdout, 'datalad %s\n' % datalad.__version__)
     # since https://github.com/datalad/datalad/pull/2733 no license in --version
-    assert_not_in("Copyright", out)
-    assert_not_in("Permission is hereby granted", out)
+    assert_not_in("Copyright", stdout)
+    assert_not_in("Permission is hereby granted", stdout)
+
+    try:
+        import datalad_container
+    except ImportError:
+        pass  # not installed, cannot test with extension
+    else:
+        stdout, stderr = run_main(['containers-list', '--version'], expect_stderr=True)
+        eq_(stdout, 'datalad_container %s\n' % datalad_container.__version__)
 
 
 def test_help_np():
@@ -109,7 +114,7 @@ def test_help_np():
     # enough of bin/datalad and .tox/py27/bin/datalad -- guarantee consistency! ;)
     ok_startswith(stdout, 'Usage: datalad')
     # Sections start/end with * if ran under DATALAD_HELP2MAN mode
-    sections = [l[1:-1] for l in filter(re.compile('^\*.*\*$').match, stdout.split('\n'))]
+    sections = [l[1:-1] for l in filter(re.compile(r'^\*.*\*$').match, stdout.split('\n'))]
     # but order is still not guaranteed (dict somewhere)! TODO
     # see https://travis-ci.org/datalad/datalad/jobs/80519004
     # thus testing sets
@@ -119,8 +124,10 @@ def test_help_np():
               'General information',
               'Global options',
               'Plumbing commands',
-              'Plugins'}:
+              }:
         assert_in(s, sections)
+        # should be present only one time!
+        eq_(stdout.count(s), 1)
 
     if not get_terminal_size()[0] or 0:
         raise SkipTest(
@@ -197,19 +204,15 @@ def test_script_shims():
         'datalad',
         'git-annex-remote-datalad-archives',
         'git-annex-remote-datalad']:
-        if not on_windows:
-            # those must be available for execution, and should not contain
-            which = runner.run(['which', script], protocol=StdOutErrCapture)['stdout']
-            # test if there is no easy install shim in there
-            with open(which.rstrip()) as f:
-                content = f.read()
-        else:
-            from distutils.spawn import find_executable
-            content = find_executable(script)
+
+        from shutil import which
+        which(script)
 
         # and let's check that it is our script
         out = runner.run([script, '--version'], protocol=StdOutErrCapture)
-        version = (out['stdout'] + out['stderr']).splitlines()[0].split(' ', 1)[1]
+        version = out['stdout'].rstrip()
+        mod, version = version.split(' ', 1)
+        assert_equal(mod, 'datalad')
         # we can get git and non git .dev version... so for now
         # relax
         get_numeric_portion = lambda v: [x for x in re.split('[+.]', v) if x.isdigit()]
@@ -284,7 +287,7 @@ def test_fail_with_short_help():
             known=["mother", "mutter", "father", "son"],
             provided="muther",
             hint="You can become one",
-            exit_code=0,  # noone forbids
+            exit_code=0,  # nobody forbids
             what="parent",
             out=out)
     assert_equal(cme.exception.code, 0)
@@ -298,15 +301,39 @@ def test_fail_with_short_help():
                  "Hint: You can become one\n")
 
 
-def test_fix_datalad_ri():
-    assert_equal(_fix_datalad_ri('/'), '/')
-    assert_equal(_fix_datalad_ri('/a/b'), '/a/b')
-    assert_equal(_fix_datalad_ri('//'), '///')
-    assert_equal(_fix_datalad_ri('///'), '///')
-    assert_equal(_fix_datalad_ri('//a'), '///a')
-    assert_equal(_fix_datalad_ri('///a'), '///a')
-    assert_equal(_fix_datalad_ri('//a/b'), '///a/b')
-    assert_equal(_fix_datalad_ri('///a/b'), '///a/b')
+def test_fail_with_short_help():
+    out = StringIO()
+    with assert_raises(SystemExit) as cme:
+        fail_with_short_help(exit_code=3, out=out)
+    assert_equal(cme.exception.code, 3)
+    assert_equal(out.getvalue(), "")
+
+    out = StringIO()
+    with assert_raises(SystemExit) as cme:
+        fail_with_short_help(msg="Failed badly", out=out)
+    assert_equal(cme.exception.code, 1)
+    assert_equal(out.getvalue(), "error: Failed badly\n")
+
+    # Suggestions, hint, etc
+    out = StringIO()
+    with assert_raises(SystemExit) as cme:
+        fail_with_short_help(
+            msg="Failed badly",
+            known=["mother", "mutter", "father", "son"],
+            provided="muther",
+            hint="You can become one",
+            exit_code=0,  # nobody forbids
+            what="parent",
+            out=out)
+    assert_equal(cme.exception.code, 0)
+    assert_equal(out.getvalue(),
+                 "error: Failed badly\n"
+                 "datalad: Unknown parent 'muther'.  See 'datalad --help'.\n\n"
+                 "Did you mean any of these?\n"
+                 "        mutter\n"
+                 "        mother\n"
+                 "        father\n"
+                 "Hint: You can become one\n")
 
 
 @with_tempfile
