@@ -200,7 +200,7 @@ class Run(Interface):
             metavar=("PATH"),
             action='append',
             doc="""A dependency for the run. Before running the command, the
-            content of this file will be retrieved. A value of "." means "run
+            content for this relative path will be retrieved. A value of "." means "run
             :command:`datalad get .`". The value can also be a glob. [CMD: This
             option can be given more than once. CMD]"""),
         outputs=Parameter(
@@ -208,7 +208,7 @@ class Run(Interface):
             dest="outputs",
             metavar=("PATH"),
             action='append',
-            doc="""Prepare this file to be an output file of the command. A
+            doc="""Prepare this relative path to be an output file of the command. A
             value of "." means "run :command:`datalad unlock .`" (and will fail
             if some content isn't present). For any other value, if the content
             of this file is present, unlock the file. Otherwise, remove it. The
@@ -804,6 +804,13 @@ def run_command(cmd, dataset=None, inputs=None, outputs=None, expand=None,
                      "If this is expected, you can save the changes with "
                      "'datalad save -d . -r -F %s'",
                      msg_path)
+            if repo.dirty and not explicit:
+                # Give clean-up hints if a formerly clean repo is left dirty
+                lgr.info(
+                    "The commands 'git clean -di' and/or 'git reset' "
+                    "could be used to get to a clean dataset state again. "
+                    "Consult their man pages for more information."
+                )
         raise exc
     elif do_save:
         with chpwd(pwd):
