@@ -26,7 +26,6 @@ from datalad.utils import (
 )
 from datalad.cmd import (
     WitlessRunner as Runner,
-    StdOutErrCapture,
 )
 
 from datalad.tests.utils import (
@@ -40,6 +39,7 @@ from datalad.tests.utils import (
     has_symlink_capability,
     OBSCURE_FILENAME,
     ok_,
+    ok_exists,
     swallow_outputs,
     with_tempfile,
     with_tree,
@@ -71,7 +71,7 @@ def test_create_raises(path, outside_path):
     assert_in_results(
         ds.create(force=False, **raw),
         status='error',
-        message='will not create a dataset in a non-empty directory, use `force` option to ignore')
+        message='will not create a dataset in a non-empty directory, use `--force` option to ignore')
     # non-empty with `force`:
     ds.create(force=True)
     # create sub outside of super:
@@ -177,13 +177,16 @@ def test_create(probe, path):
     assert_repo_status(ds.path, annex=True)
 
     # check default backend
-    eq_(ds.config.get("annex.backends"), 'MD5E')
+    (ds.pathobj / "f1").write_text("1")
+    ds.save()
+    eq_(ds.repo.get_file_backend(["f1"]), ['MD5E'])
+
     if not ar.is_managed_branch():
         eq_(ds.config.get("core.sharedrepository"), '2')
     # check description in `info`
     cmlout = ds.repo.call_annex(['info'])
     assert_in('funny [here]', cmlout)
-    # check datset ID
+    # check dataset ID
     eq_(ds.config.get_value('datalad.dataset', 'id'),
         ds.id)
 
@@ -353,7 +356,7 @@ def test_nested_create(path):
     assert_in_results(
         ds.create(lvl2relpath, **raw),
         status='error',
-        message='will not create a dataset in a non-empty directory, use `force` option to ignore')
+        message='will not create a dataset in a non-empty directory, use `--force` option to ignore')
     # XXX even force doesn't help, because (I assume) GitPython doesn't update
     # its representation of the Git index properly
     ds.create(lvl2relpath, force=True)
@@ -507,3 +510,24 @@ def test_gh2927(path, linkpath):
     ds.create('subds_clean')
     assert_status('ok', ds.create(op.join('subds_clean', 'subds_lvl1_clean'),
                                   result_xfm=None, return_type='list'))
+
+
+@with_tempfile(mkdir=True)
+def check_create_initopts_form(form, path):
+    path = Path(path)
+
+    template_dir = path / "templates"
+    template_dir.mkdir()
+    (template_dir / "foo").write_text("")
+
+    forms = {"list": [f"--template={template_dir}"],
+             "dict": {"template": str(template_dir)}}
+
+    ds = Dataset(path / "ds")
+    ds.create(initopts=forms[form])
+    ok_exists(ds.repo.dot_git / "foo")
+
+
+def test_create_initopts_form():
+    yield check_create_initopts_form, "dict"
+    yield check_create_initopts_form, "list"
