@@ -14,10 +14,12 @@ import logging
 lgr = logging.getLogger('datalad.customremotes.datalad')
 
 from .base import AnnexCustomRemote
-from ..dochelpers import exc_str
 
 from ..downloaders.providers import Providers
-from ..support.exceptions import TargetFileAbsent
+from ..support.exceptions import (
+    CapturedException,
+    TargetFileAbsent,
+)
 from .main import main as super_main
 
 
@@ -70,7 +72,8 @@ class DataladAnnexCustomRemote(AnnexCustomRemote):
             resp = ["CHECKURL-CONTENTS", size] \
                 + ([status.filename] if status.filename else [])
         except Exception as exc:
-            self.debug("Failed to check url %s: %s" % (url, exc_str(exc)))
+            ce = CapturedException(exc)
+            self.debug("Failed to check url %s: %s" % (url, ce))
             resp = ["CHECKURL-FAILURE"]
         self.send(*resp)
 
@@ -102,14 +105,16 @@ class DataladAnnexCustomRemote(AnnexCustomRemote):
                 # we can connect to that server but that specific url is N/A,
                 # probably check the connection etc
             except TargetFileAbsent as exc:
-                self.debug("Target url %s file seems to be missing: %s" % (url, exc_str(exc)))
+                ce = CapturedException(exc)
+                self.debug("Target url %s file seems to be missing: %s" % (url, ce))
                 if not resp:
                     # if it is already marked as UNKNOWN -- let it stay that way
                     # but if not -- we might as well say that we can no longer access it
                     resp = "CHECKPRESENT-FAILURE"
             except Exception as exc:
+                ce = CapturedException(exc)
                 resp = "CHECKPRESENT-UNKNOWN"
-                self.debug("Failed to check status of url %s: %s" % (url, exc_str(exc)))
+                self.debug("Failed to check status of url %s: %s" % (url, ce))
         if resp is None:
             resp = "CHECKPRESENT-UNKNOWN"
         self.send(resp, key)
@@ -155,8 +160,9 @@ class DataladAnnexCustomRemote(AnnexCustomRemote):
                 self.send('TRANSFER-SUCCESS', cmd, key)
                 return
             except Exception as exc:
+                ce = CapturedException(exc)
                 self.debug("Failed to download url %s for key %s: %s"
-                           % (url, key, exc_str(exc)))
+                           % (url, key, ce))
 
         raise RuntimeError(
             "Failed to download from any of %d locations" % len(urls)
