@@ -12,18 +12,15 @@
 __docformat__ = 'restructuredtext'
 
 from distutils.version import LooseVersion
-from glob import glob
 import logging
 import os
 from os.path import (
     curdir,
-    dirname,
     join as opj,
     normpath,
     relpath,
 )
 
-import datalad
 from datalad import ssh_manager
 
 from datalad.ui import ui
@@ -35,10 +32,8 @@ from datalad.cmd import (
 )
 from datalad.consts import (
     TIMESTAMP_FMT,
-    WEB_HTML_DIR,
     WEB_META_LOG
 )
-from datalad.dochelpers import exc_str
 from datalad.distribution.siblings import (
     _DelayedSuper,
     Siblings,
@@ -74,6 +69,7 @@ from datalad.support.constraints import (
     EnsureStr,
 )
 from datalad.support.exceptions import (
+    CapturedException,
     InsufficientArgumentsError,
     MissingExternalDependency,
 )
@@ -98,7 +94,7 @@ from datalad.utils import on_windows
 lgr = logging.getLogger('datalad.distribution.create_sibling')
 # Window's own mkdir command creates intermediate directories by default
 # and does not take flags: https://github.com/datalad/datalad/issues/5211
-mkdir_cmd = "mkdir" if on_windows else "mkdir -p" 
+mkdir_cmd = "mkdir" if on_windows else "mkdir -p"
 
 
 class _RunnerAdapter(WitlessRunner):
@@ -306,8 +302,6 @@ def _create_dataset_sibling(
             install_postupdate_hook = CreateSibling._has_active_postupdate(
                 delayed_super, name, shell)
 
-
-
     if group:
         # Either repository existed before or a new directory was created for it,
         # set its group to a desired one if was provided with the same chgrp
@@ -360,9 +354,10 @@ def _create_dataset_sibling(
             shell("git -C {} config receive.denyCurrentBranch updateInstead".format(
                 sh_quote(remoteds_path)))
         except CommandError as e:
+            ce = CapturedException(e)
             lgr.error("git config failed at remote location %s.\n"
                       "You will not be able to push to checked out "
-                      "branch. Error: %s", remoteds_path, exc_str(e))
+                      "branch. Error: %s", remoteds_path, ce)
     else:
         lgr.error("Git version >= 2.4 needed to configure remote."
                   " Version detected on server: %s\nSkipping configuration"
@@ -388,8 +383,9 @@ def _create_dataset_sibling(
             CreateSibling.create_postupdate_hook(
                 remoteds_path, shell, ds)
         except CommandError as e:
+            ce = CapturedException(e)
             lgr.error("Failed to add json creation command to post update "
-                      "hook.\nError: %s" % exc_str(e))
+                      "hook.\nError: %s", ce)
 
     return remoteds_path
 
@@ -436,8 +432,6 @@ class CreateSibling(Interface):
     mechanism is provided to produce a flat list of datasets (see
     --target-dir).
     """
-    # XXX prevent common args from being added to the docstring
-    _no_eval_results = True
 
     _params_ = dict(
         # TODO: Figure out, whether (and when) to use `sshurl` as push url
@@ -555,9 +549,9 @@ class CreateSibling(Interface):
         since=Parameter(
             args=("--since",),
             constraints=EnsureStr() | EnsureNone(),
-            doc="""limit processing to datasets that have been changed since a given
-            state (by tag, branch, commit, etc). This can be used to create siblings
-            for recently added subdatasets."""),
+            doc="""limit processing to subdatasets that have been changed since
+            a given state (by tag, branch, commit, etc). This can be used to
+            create siblings for recently added subdatasets."""),
     )
 
     @staticmethod
@@ -578,17 +572,35 @@ class CreateSibling(Interface):
                  annex_wanted=None, annex_group=None, annex_groupwanted=None,
                  inherit=False,
                  since=None):
+        if ui:
+            # the webui has been moved to the deprecated extension
+            try:
+                from datalad_deprecated.sibling_webui \
+                    import upload_web_interface
+            except Exception as e:
+                # we could just test for ModuleNotFoundError (which should be
+                # all that would happen with PY3.6+, but be a little more robust
+                # and use the pattern from duecredit
+                if type(e).__name__ not in ('ImportError', 'ModuleNotFoundError'):
+                    lgr.error("Failed to import datalad_deprecated.sibling_webui "
+                              "due to %s", str(e))
+                raise RuntimeError(
+                    "The DataLad web UI has been moved to an extension "
+                    "package. Please install the Python package "
+                    "`datalad_deprecated` to be able to deploy it."
+                )
         #
         # nothing without a base dataset
         #
         ds = require_dataset(dataset, check_installed=True,
-                             purpose='creating a sibling')
+                             purpose='create sibling(s)')
         refds_path = ds.path
 
         #
         # all checks that are possible before we start parsing the dataset
         #
-
+        if since and not recursive:
+            raise ValueError("The use of 'since' requires 'recursive'")
         # possibly use sshurl to get the name in case if not specified
         if not sshurl:
             if not inherit:
@@ -604,7 +616,8 @@ class CreateSibling(Interface):
             try:
                 sshurl = CreateSibling._get_remote_url(ds, name)
             except Exception as exc:
-                lgr.debug('%s does not know about url for %s: %s', ds, name, exc_str(exc))
+                ce = CapturedException(exc)
+                lgr.debug('%s does not know about url for %s: %s', ds, name, ce)
         elif inherit:
             raise ValueError(
                 "For now, for clarity not allowing specifying a custom sshurl "
@@ -622,7 +635,7 @@ class CreateSibling(Interface):
                 )
             super_url = CreateSibling._get_remote_url(super_ds, name)
             # for now assuming hierarchical setup
-            # (TODO: to be able to destinguish between the two, probably
+            # (TODO: to be able to distinguish between the two, probably
             # needs storing datalad.*.target_dir to have %RELNAME in there)
             sshurl = slash_join(super_url, relpath(refds_path, super_ds.path))
 
@@ -636,7 +649,7 @@ class CreateSibling(Interface):
 
         if not name:
             name = sibling_ri.hostname if ssh_sibling else "local"
-            lgr.debug(
+            lgr.info(
                 "No sibling name given. Using %s'%s' as sibling name",
                 "URL hostname " if ssh_sibling else "",
                 name)
@@ -648,39 +661,46 @@ class CreateSibling(Interface):
             active_branch = ds.repo.get_active_branch()
             since = '%s/%s' % (name, active_branch)
 
-        #
-        # parse the base dataset to find all subdatasets that need processing
-        #
         to_process = []
-        cand_ds = [
-            Dataset(r['path'])
-            for r in diff_dataset(
-                ds,
-                fr=since,
-                to=None,
-                # make explicit, but doesn't matter, no recursion in diff()
-                constant_refs=True,
-                # contrain to the paths of all locally existing subdatasets
-                path=[
-                    sds['path']
-                    for sds in ds.subdatasets(
-                        recursive=recursive,
-                        recursion_limit=recursion_limit,
-                        fulfilled=True,
-                        result_renderer=None)
-                ],
-                # save cycles, we are only looking for datasets
-                annex=None,
-                untracked='no',
-                # recursion was done faster by subdatasets()
-                recursive=False,
-                # save cycles, we are only looking for datasets
-                eval_file_type=False,
-            )
-            if r.get('type') == 'dataset' and r.get('state', None) != 'clean'
-        ]
-        # check remotes setup
-        for d in cand_ds if since else ([ds] + cand_ds):
+        if recursive:
+            #
+            # parse the base dataset to find all subdatasets that need processing
+            #
+            cand_ds = [
+                Dataset(r['path'])
+                for r in diff_dataset(
+                    ds,
+                    fr=since,
+                    to=None,
+                    # make explicit, but doesn't matter, no recursion in diff()
+                    constant_refs=True,
+                    # contrain to the paths of all locally existing subdatasets
+                    path=[
+                        sds['path']
+                        for sds in ds.subdatasets(
+                            recursive=recursive,
+                            recursion_limit=recursion_limit,
+                            fulfilled=True,
+                            result_renderer=None)
+                    ],
+                    # save cycles, we are only looking for datasets
+                    annex=None,
+                    untracked='no',
+                    # recursion was done faster by subdatasets()
+                    recursive=False,
+                    # save cycles, we are only looking for datasets
+                    eval_file_type=False,
+                )
+                if r.get('type') == 'dataset' and r.get('state', None) != 'clean'
+            ]
+            if not since:
+                # not only subdatasets
+                cand_ds = [ds] + cand_ds
+        else:
+            # only the current ds
+            cand_ds = [ds]
+        # check remotes setup()
+        for d in cand_ds:
             d_repo = d.repo
             if d_repo is None:
                 continue
@@ -708,6 +728,7 @@ class CreateSibling(Interface):
             if name in checkds_remotes and existing in ('error', 'skip'):
                 yield dict(
                     res,
+                    sibling_name=name,
                     status='error' if existing == 'error' else 'notneeded',
                     message=(
                         "sibling '%s' already configured (specify alternative "
@@ -785,6 +806,7 @@ class CreateSibling(Interface):
                 annex_groupwanted,
                 inherit
             )
+            currentds_ap["sibling_name"] = name
             if not path:
                 # nothing new was created
                 # TODO is 'notneeded' appropriate in this case?
@@ -797,14 +819,17 @@ class CreateSibling(Interface):
 
             # publish web-interface to root dataset on publication server
             if current_ds.path == refds_path and ui:
+                from datalad_deprecated.sibling_webui import upload_web_interface
                 lgr.info("Uploading web interface to %s", path)
                 try:
-                    CreateSibling.upload_web_interface(path, shell, shared, ui)
+                    upload_web_interface(path, shell, shared, ui)
                 except CommandError as e:
+                    ce = CapturedException(e)
                     currentds_ap['status'] = 'error'
                     currentds_ap['message'] = (
                         "failed to push web interface to the remote datalad repository (%s)",
-                        exc_str(e))
+                        ce)
+                    currentds_ap['exception'] = ce
                     yield currentds_ap
                     yielded.add(currentds_ap['path'])
                     continue
@@ -820,10 +845,12 @@ class CreateSibling(Interface):
                       "&& ( [ -x hooks/post-update ] && hooks/post-update || true )"
                       "".format(sh_quote(_path_(path, ".git"))))
             except CommandError as e:
+                ce = CapturedException(e)
                 currentds_ap['status'] = 'error'
                 currentds_ap['message'] = (
                     "failed to run post-update hook under remote path %s (%s)",
-                    path, exc_str(e))
+                    path, ce)
+                currentds_ap['exception'] = ce
                 yield currentds_ap
                 yielded.add(currentds_ap['path'])
                 continue
@@ -869,11 +896,11 @@ class CreateSibling(Interface):
             )
             shared = out.strip()
         except CommandError as e:
+            ce = CapturedException(e)
             lgr.debug(
                 "Could not figure out remote shared setting of %s for %s due "
                 "to %s",
-                ds, name, exc_str(e)
-            )
+                ds, name, ce)
             # could well be ok if e.g. not shared
             # TODO: more detailed analysis may be?
         return shared
@@ -899,10 +926,11 @@ class CreateSibling(Interface):
             assert out in ('yes', 'no')
             has_active_post_update = out == "yes"
         except CommandError as e:
+            ce = CapturedException(e)
             lgr.debug(
                 "Could not figure out either %s on remote %s has active "
                 "post_update hook due to %s",
-                ds, name, exc_str(e)
+                ds, name, ce
             )
         return has_active_post_update
 
@@ -926,8 +954,9 @@ class CreateSibling(Interface):
         try:
             ssh(cmd)
         except CommandError as e:
+            ce = CapturedException(e)
             lgr.error("Initialization of remote git repository failed at %s."
-                      "\nError: %s\nSkipping ..." % (path, exc_str(e)))
+                      "\nError: %s\nSkipping ...", path, ce)
             return False
 
         if isinstance(dataset.repo, AnnexRepo):
@@ -940,8 +969,9 @@ class CreateSibling(Interface):
                         if description else '')
                 )
             except CommandError as e:
+                ce = CapturedException(e)
                 lgr.error("Initialization of remote git annex repository failed at %s."
-                          "\nError: %s\nSkipping ..." % (path, exc_str(e)))
+                          "\nError: %s\nSkipping ...", path, ce)
                 return False
         return True
 
@@ -993,53 +1023,3 @@ done
             ssh.put(tempf, hook_remote_target)
         # and make it executable
         ssh('chmod +x {}'.format(sh_quote(hook_remote_target)))
-
-    @staticmethod
-    def upload_web_interface(path, ssh, shared, ui):
-        # path to web interface resources on local
-        webui_local = opj(dirname(datalad.__file__), 'resources', 'website')
-        # local html to dataset
-        html_local = opj(webui_local, "index.html")
-
-        # name and location of web-interface html on target
-        html_targetname = {True: ui, False: "index.html"}[isinstance(ui, str)]
-        html_target = opj(path, html_targetname)
-
-        # upload ui html to target
-        ssh.put(html_local, html_target)
-
-        # upload assets to the dataset
-        webresources_local = opj(webui_local, 'assets')
-        webresources_remote = opj(path, WEB_HTML_DIR)
-        ssh('{} {}'.format(mkdir_cmd, sh_quote(webresources_remote)))
-        ssh.put(webresources_local, webresources_remote, recursive=True)
-
-        # minimize and upload js assets
-        for js_file in glob(opj(webresources_local, 'js', '*.js')):
-            with open(js_file) as asset:
-                try:
-                    from jsmin import jsmin
-                    # jsmin = lambda x: x   # no minimization
-                    minified = jsmin(asset.read())                      # minify asset
-                except ImportError:
-                    lgr.warning(
-                        "Will not minify web interface javascript, no jsmin available")
-                    minified = asset.read()                             # no minify available
-                with make_tempfile(content=minified) as tempf:          # write minified to tempfile
-                    js_name = js_file.split('/')[-1]
-                    ssh.put(tempf, opj(webresources_remote, 'assets', 'js', js_name))  # and upload js
-
-        # explicitly make web+metadata dir of dataset world-readable, if shared set to 'all'
-        mode = None
-        if shared in (True, 'true', 'all', 'world', 'everybody'):
-            mode = 'a+rX'
-        elif shared == 'group':
-            mode = 'g+rX'
-        elif str(shared).startswith('0'):
-            mode = shared
-
-        if mode:
-            ssh('chmod -R {} {} {}'.format(
-                mode,
-                sh_quote(dirname(webresources_remote)),
-                sh_quote(opj(path, 'index.html'))))
