@@ -61,6 +61,7 @@ from datalad.tests.utils import (
     assert_status,
     assert_in_results,
     DEFAULT_BRANCH,
+    DEFAULT_REMOTE,
     ok_startswith,
     serve_path_via_http,
     swallow_logs,
@@ -72,7 +73,6 @@ from datalad.tests.utils import (
     slow,
     usecase,
     get_datasets_topdir,
-    known_failure_appveyor,
     known_failure_windows,
     known_failure_githubci_win,
 )
@@ -174,9 +174,7 @@ def test_invalid_args(path):
 #    assert_in(crcns.path, ds.get_subdatasets(absolute=True))
 
 
-@known_failure_appveyor
 @skip_if_no_network
-@use_cassette('test_install_crcns')
 @with_tree(tree={'sub': {}})
 def test_install_datasets_root(tdir):
     with chpwd(tdir):
@@ -444,7 +442,6 @@ def test_install_into_dataset(source, top_path):
 @known_failure_windows  #FIXME
 @usecase  # 39.3074s
 @skip_if_no_network
-@use_cassette('test_install_crcns')
 @with_tempfile
 def test_failed_install_multiple(top_path):
     ds = create(top_path)
@@ -873,7 +870,7 @@ def test_install_subds_from_another_remote(topdir):
         clone1.create_sibling('ssh://datalad-test%s/%s' % (PathRI(getpwd()).posixpath, clone2_), name=clone2_)
 
         # print("Creating clone2")
-        clone1.publish(to=clone2_)
+        clone1.push(to=clone2_)
         clone2 = Dataset(clone2_)
         # print("Initiating subdataset")
         clone2.create('subds1')
@@ -893,7 +890,8 @@ def check_datasets_datalad_org(suffix, tdir):
     # Apparently things can break, especially with introduction of the
     # smart HTTP backend for apache2 etc
     ds = install(tdir, source='///dicoms/dartmouth-phantoms/bids_test6-PD+T2w' + suffix)
-    eq_(ds.config.get('remote.origin.annex-ignore', None), None)
+    eq_(ds.config.get(f'remote.{DEFAULT_REMOTE}.annex-ignore', None),
+        None)
     # assert_result_count and not just assert_status since for some reason on
     # Windows we get two records due to a duplicate attempt (as res[1]) to get it
     # again, which is reported as "notneeded".  For the purpose of this test
@@ -919,3 +917,41 @@ def test_relpath_semantics(path):
         sub = install(
             dataset='super', source='subsrc', path=op.join('super', 'sub'))
         eq_(sub.path, op.join(super.path, 'sub'))
+
+
+def _create_test_install_recursive_github(path):  # pragma: no cover
+    # to be ran once to populate a hierarchy of test datasets on github
+    # Making it a full round-trip would require github credentials on CI etc
+    ds = create(opj(path, "testrepo  gh"))
+    # making them with spaces and - to ensure that we consistently use the mapping
+    # for create and for get/clone/install
+    ds.create("sub _1")
+    ds.create("sub _1/d/sub_-  1")
+    import datalad.distribution.create_sibling_github  # to bind API
+    ds.create_sibling_github(
+        "testrepo  gh",
+        github_organization='datalad',
+        recursive=True,
+        # yarik forgot to push first, "replace" is not working in non-interactive IIRC
+        # existing='reconfigure'
+    )
+    return ds.push(recursive=True, to='github')
+
+
+@skip_if_no_network
+@with_tempfile(mkdir=True)
+def test_install_recursive_github(path):
+    # test recursive installation of a hierarchy of datasets created on github
+    # using datalad create-sibling-github.  Following invocation was used to poplate it
+    #
+    # out = _create_test_install_recursive_github(path)
+
+    # "testrepo  gh" was mapped by our sanitization in create_sibling_github to testrepo_gh, thus
+    for i, url in enumerate([
+        'https://github.com/datalad/testrepo_gh',
+        # optionally made available to please paranoids, but with all takes too long (22sec)
+        #'https://github.com/datalad/testrepo_gh.git',
+        #'git@github.com:datalad/testrepo_gh.git',
+    ]):
+        ds = install(source=url, path=opj(path, "clone%i" % i), recursive=True)
+        eq_(len(ds.subdatasets(recursive=True, fulfilled=True)), 2)
