@@ -32,6 +32,7 @@ from datalad.tests.utils import (
     with_tempfile, with_testrepos,
     assert_false,
     assert_in,
+    assert_in_results,
     assert_not_in,
     assert_raises,
     assert_status,
@@ -39,9 +40,15 @@ from datalad.tests.utils import (
     with_sameas_remote,
     eq_,
     ok_,
+    serve_path_via_http,
+    DEFAULT_BRANCH,
+    DEFAULT_REMOTE,
 )
 
-from datalad.utils import Path
+from datalad.utils import (
+    on_windows,
+    Path,
+)
 
 
 # work on cloned repos to be safer
@@ -110,11 +117,34 @@ def test_siblings(origin, repo_path, local_clone_path):
                    result_renderer=None)
     assert_status('ok', res)
     assert_not_in("test-remote", source.repo.get_remotes())
+    # remove again (with result renderer to smoke-test a renderer
+    # special case for this too)
+    res = siblings('remove', dataset=source, name="test-remote")
+    assert_status('notneeded', res)
+
     res = siblings('add', dataset=source, name="test-remote",
                    url=httpurl1, on_failure='ignore',
                    result_renderer=None)
     assert_status('ok', res)
 
+    # add another remove with a publication dependency
+    # again pre-pollute config
+    depvar = 'remote.test-remote2.datalad-publish-depends'
+    pushvar = 'remote.test-remote2.push'
+    source.config.add(depvar, 'stupid', where='local')
+    source.config.add(pushvar, 'senseless', where='local')
+    res = siblings('configure', dataset=source, name="test-remote2",
+                   url=httpurl2, on_failure='ignore',
+                   publish_depends='test-remote',
+                   # just for smoke testing
+                   publish_by_default=DEFAULT_BRANCH,
+                   result_renderer=None)
+    assert_status('ok', res)
+    # config replaced with new setup
+    #source.config.reload(force=True)
+    eq_(source.config.get(depvar, None), 'test-remote')
+    eq_(source.config.get(pushvar, None), DEFAULT_BRANCH)
+
     # add to another remote automagically taking it from the url
     # and being in the dataset directory
     with chpwd(source.path):
@@ -135,7 +165,7 @@ def test_siblings(origin, repo_path, local_clone_path):
         source.repo.get_remote_url("test-remote"))
 
     # no longer a use case, I would need additional convincing that
-    # this is anyhow useful other then tripple checking other peoples
+    # this is anyhow useful other then triple checking other peoples
     # errors. for an actual check use 'query'
     # maybe it could be turned into a set of warnings when `configure`
     # alters an existing setting, but then why call configure, if you
@@ -242,6 +272,10 @@ def test_siblings(origin, repo_path, local_clone_path):
                          relpath(str(r['path']), source.path))))
         # https://github.com/datalad/datalad/issues/3951
         ok_(not pushurl)  # no pushurl should be defined
+    # 5621: Users shouldn't pass identical names for remote & common data source
+    assert_raises(ValueError, siblings, 'add', dataset=source, name='howdy',
+                  url=httpurl1, as_common_datasrc='howdy')
+
 
 @with_tempfile(mkdir=True)
 def test_here(path):
@@ -260,6 +294,14 @@ def test_here(path):
     assert_in('annex-bare', here)
     assert_in('available_local_disk_space', here)
 
+    # unknown sibling query errors
+    res = ds.siblings(
+        'query',
+        name='notthere',
+        on_failure='ignore',
+        result_renderer=None)
+    assert_status('error', res)
+
     # set a description
     res = ds.siblings(
         'configure',
@@ -285,6 +327,28 @@ def test_here(path):
     eq_(res, newres)
 
 
+@with_tempfile(mkdir=True)
+def test_no_annex(path):
+    # few smoke tests regarding the 'here' sibling
+    ds = create(path, annex=False)
+    res = ds.siblings(
+        'configure',
+        name='here',
+        description='very special',
+        on_failure='ignore',
+        result_renderer=None)
+    assert_status('impossible', res)
+
+    res = ds.siblings(
+        'enable',
+        name='doesnotmatter',
+        on_failure='ignore',
+        result_renderer=None)
+    assert_in_results(
+        res, status='impossible',
+        message='cannot enable sibling of non-annex dataset')
+
+
 @with_tempfile()
 @with_tempfile()
 def test_arg_missing(path, path2):
@@ -300,6 +364,38 @@ def test_arg_missing(path, path2):
         'ok',
         ds.siblings(
             'add', url=path2, name='somename'))
+    # trigger some name guessing functionality that will still not
+    # being able to end up using a hostnames-spec despite being
+    # given a URL
+    if not on_windows:
+        # the trick with the file:// URL creation only works on POSIX
+        # the underlying tested code here is not about paths, though,
+        # so it is good enough to run this on POSIX system to be
+        # reasonably sure that things work
+        assert_raises(
+            InsufficientArgumentsError,
+            ds.siblings,
+            'add',
+            url=f'file://{path2}',
+        )
+
+    # there is no name guessing with 'configure'
+    assert_in_results(
+        ds.siblings('configure', url='http://somename', on_failure='ignore'),
+        status='error',
+        message='need sibling `name` for configuration')
+
+    # needs a URL
+    assert_raises(
+        InsufficientArgumentsError, ds.siblings, 'add', name='somename')
+    # just pushurl is OK
+    assert_status('ok', ds.siblings('add', pushurl=path2, name='somename2'))
+
+    # needs group with groupwanted
+    assert_raises(
+        InsufficientArgumentsError,
+        ds.siblings, 'add', url=path2, name='somename',
+        annex_groupwanted='whatever')
 
 
 @with_sameas_remote
@@ -314,6 +410,26 @@ def test_sibling_enable_sameas(repo, clone_path):
     ds_cloned = clone(ds.path, clone_path)
 
     assert_false(ds_cloned.repo.file_has_content("f0"))
+    # does not work without a name
+    res = ds_cloned.siblings(
+        action="enable",
+        result_renderer=None,
+        on_failure='ignore',
+    )
+    assert_in_results(
+        res, status='error', message='require `name` of sibling to enable')
+    # does not work with the wrong name
+    res = ds_cloned.siblings(
+        action="enable",
+        name='wrong',
+        result_renderer=None,
+        on_failure='ignore',
+    )
+    assert_in_results(
+        res, status='impossible',
+        message=("cannot enable sibling '%s', not known", 'wrong')
+    )
+    # works with the right name
     res = ds_cloned.siblings(action="enable", name="r_rsync")
     assert_status("ok", res)
     ds_cloned.get(path=["f0"])
@@ -390,3 +506,77 @@ def test_bf3733(path):
         name="imaginary",
         path=ds.path,
     )
+
+
+@with_tempfile(mkdir=True)
+@with_tempfile(mkdir=True)
+@with_tempfile(mkdir=True)
+@with_tempfile(mkdir=True)
+@serve_path_via_http
+def test_as_common_datasource(testbed, viapath, viaurl, remotepath, url):
+    ds = Dataset(remotepath).create()
+    (ds.pathobj / 'testfile').write_text('likemagic')
+    (ds.pathobj / 'testfile2').write_text('likemagic2')
+    ds.save()
+
+    # make clonable via HTTP
+    ds.repo.call_git(['update-server-info'])
+
+    # this does not work for remotes that have path URLs
+    ds_frompath = clone(source=remotepath, path=viapath)
+    res = ds_frompath.siblings(
+        'configure',
+        name=DEFAULT_REMOTE,
+        as_common_datasrc='mike',
+        on_failure='ignore',
+        result_renderer=None,
+    )
+    assert_in_results(
+        res,
+        status='impossible',
+        message='cannot configure as a common data source, URL protocol '
+                'is not http or https',
+    )
+
+    # but it works for HTTP
+    ds_fromurl = clone(source=url, path=viaurl)
+    res = ds_fromurl.siblings(
+        'configure',
+        name=DEFAULT_REMOTE,
+        as_common_datasrc='mike2',
+        result_renderer=None,
+    )
+    assert_status('ok', res)
+    # same thing should be possible by adding a fresh remote
+    res = ds_fromurl.siblings(
+        'add',
+        name='fresh',
+        url=url,
+        as_common_datasrc='fresh-sr',
+        result_renderer=None,
+    )
+    assert_status('ok', res)
+
+    # now try if it works. we will clone the clone, and get a repo that does
+    # not know its ultimate origin. still, we should be able to pull data
+    # from it via the special remote
+    testbed = clone(source=ds_fromurl, path=testbed)
+    assert_status('ok', testbed.get('testfile'))
+    eq_('likemagic', (testbed.pathobj / 'testfile').read_text())
+    # and the other one
+    assert_status('ok', testbed.get('testfile2'))
+
+
+@with_tempfile(mkdir=True)
+@with_tempfile(mkdir=True)
+def test_specialremote(dspath, remotepath):
+    ds = Dataset(dspath).create()
+    ds.repo.call_annex(
+        ['initremote', 'myremote', 'type=directory',
+         f'directory={remotepath}', 'encryption=none'])
+    res = ds.siblings('query', result_renderer=None)
+    assert_in_results(
+        res,
+        **{'name': 'myremote',
+           'annex-type': 'directory',
+           'annex-directory': remotepath})
