@@ -8,15 +8,21 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Tests for http downloader"""
 
+import builtins
+import os
+import re
 import time
 from calendar import timegm
-import re
-
-import os
-import builtins
 from os.path import join as opj
 
 from datalad.downloaders.tests.utils import get_test_providers
+from datalad.support.network import (
+    download_url,
+    get_url_straight_filename,
+)
+from datalad.utils import ensure_unicode
+
+from ...support.exceptions import AccessFailedError
 from ..base import (
     BaseDownloader,
     DownloadError,
@@ -31,18 +37,10 @@ from ..credentials import (
 from ..http import (
     HTMLFormAuthenticator,
     HTTPBaseAuthenticator,
-    HTTPDownloader,
     HTTPBearerTokenAuthenticator,
+    HTTPDownloader,
     process_www_authenticate,
 )
-from ...support.exceptions import AccessFailedError
-from datalad.support.network import (
-    download_url,
-    get_url_straight_filename,
-)
-from datalad.utils import (
-    ensure_unicode,
-)
 
 # BTW -- mock_open is not in mock on wheezy (Debian 7.x)
 try:
@@ -56,6 +54,13 @@ except (ImportError, AttributeError):
     httpretty = NoHTTPPretty()
 
 from unittest.mock import patch
+
+from ...support.exceptions import (
+    AccessDeniedError,
+    AnonymousAccessDeniedError,
+)
+from ...support.network import get_url_disposition_filename
+from ...support.status import FileStatus
 from ...tests.utils import (
     SkipTest,
     assert_equal,
@@ -66,7 +71,7 @@ from ...tests.utils import (
     assert_raises,
     known_failure_githubci_win,
     ok_file_has_content,
-    serve_path_via_http, with_tree,
+    serve_path_via_http,
     skip_if,
     skip_if_no_network,
     swallow_logs,
@@ -76,14 +81,9 @@ from ...tests.utils import (
     with_memory_keyring,
     with_tempfile,
     with_testsui,
+    with_tree,
     without_http_proxy,
 )
-from ...support.exceptions import (
-    AccessDeniedError,
-    AnonymousAccessDeniedError,
-)
-from ...support.status import FileStatus
-from ...support.network import get_url_disposition_filename
 from ...utils import read_file
 
 
@@ -170,7 +170,7 @@ def test_HTTPDownloader_basic(toppath, topurl):
     # and it still results in some warning being spit out
     # Note: we need to avoid mocking opening of the lock file!
     with swallow_logs(), \
-         patch.object(builtins, 'open', fake_open(write_=_raise_IOError, skip_regex='.*\.lck$')):
+         patch.object(builtins, 'open', fake_open(write_=_raise_IOError, skip_regex=r'.*\.lck$')):
         assert_raises(DownloadError, download, furl, tfpath, overwrite=True)
 
     # incomplete download scenario - should have 3 tries
@@ -540,7 +540,7 @@ def test_HTMLFormAuthenticator_httpretty(d):
     content = read_file(fpath)
     assert_equal(content, "correct body")
 
-    # Unsuccesfull scenarios to test:
+    # Unsuccessful scenarios to test:
     # the provided URL at the end 404s, or another failure (e.g. interrupted download)
 
 
@@ -609,7 +609,7 @@ def check_httpretty_authfail404(exp_called, d):
 def test_auth_bytes_content():
     # Our regexes are strings, but we can get content in bytes:
     # I am not sure yet either we shouldn't just skip then testing for regex,
-    # but we definetely should not crash.
+    # but we definitely should not crash.
     authenticator = HTTPBaseAuthenticator(failure_re="Failed")
     authenticator.check_for_auth_failure(b"bytes")
     # but ATM we do test bytes content, let's ENSURE that!
@@ -827,7 +827,7 @@ def test_lorisadapter(d, keyring):
 @serve_path_via_http
 def test_download_url(toppath, topurl):
     furl = "%sfile.dat" % topurl
-    # fails if URL is disfunctional
+    # fails if URL is dysfunctional
     assert_raises(DownloadError, download_url, furl + 'magic', toppath)
 
     # working download
