@@ -20,6 +20,7 @@ from ...tests.utils import (
     assert_raises,
     integration,
     skip_if_no_network,
+    skip_if_no_module,
     SkipTest,
     swallow_outputs,
     turtle,
@@ -27,7 +28,6 @@ from ...tests.utils import (
     with_tempfile,
     with_testsui,
 )
-from ...dochelpers import exc_str
 from ...downloaders.base import DownloadError
 from ...support.exceptions import AccessDeniedError
 
@@ -36,15 +36,10 @@ from ...utils import (
 )
 
 from ...support import path as op
-
-try:
-    import boto
-except Exception as e:
-    raise SkipTest("boto module is not available: %s" % exc_str(e))
-
 from .utils import get_test_providers
 from .test_http import check_download_external_url
 
+skip_if_no_module('boto')
 skip_if_no_network()  # TODO: provide persistent vcr fixtures for the tests
 
 url_2versions_nonversioned1 = 's3://datalad-test0-versioned/2versions-nonversioned1.txt'
@@ -293,4 +288,4 @@ def _test_expiring_token(outdir):
         ok_file_has_content(outpath, "version1")
         os.unlink(outpath)
         sleep(1)
-    assert len(generated) == 2
\ No newline at end of file
+    assert len(generated) == 2
