@@ -10,7 +10,8 @@
 
 from unittest import SkipTest
 
-from datalad.downloaders import Providers
+from datalad.downloaders.providers import Providers
+
 
 def get_test_providers(url=None, reload=False):
     """Return reusable instance of our global providers + verify credentials for url"""
@@ -24,4 +25,4 @@ def get_test_providers(url=None, reload=False):
         elif not provider.credential.is_known:
             raise SkipTest("This test requires known credentials for %s" % provider.credential.name)
     return _test_providers
-get_test_providers.__test__ = False
\ No newline at end of file
+get_test_providers.__test__ = False
