@@ -29,7 +29,6 @@ from ..distribution.dataset import EnsureDataset
 from ..distribution.dataset import path_under_rev_dataset
 from ..distribution.dataset import require_dataset
 from ..distribution.dataset import resolve_path
-from ..dochelpers import exc_str
 from ..support.annexrepo import AnnexRepo
 from ..support.param import Parameter
 from ..support.constraints import EnsureStr, EnsureNone
@@ -38,7 +37,7 @@ from ..support.exceptions import (
     CommandError,
     NoDatasetFound,
 )
-
+from datalad.downloaders.providers import Provider
 from logging import getLogger
 lgr = getLogger('datalad.api.download-url')
 
@@ -48,13 +47,14 @@ class DownloadURL(Interface):
     """Download content
 
     It allows for a uniform download interface to various supported URL
-    schemes, re-using or asking for authentication details maintained by
-    datalad.
+    schemes (see command help for details), re-using or asking for
+    authentication details maintained by datalad.
     """
 
     _params_ = dict(
         urls=Parameter(
-            doc="URL(s) to be downloaded",
+            doc="""URL(s) to be downloaded. Supported protocols: {}""".format(
+                ", ".join(map(repr, sorted(Provider.DOWNLOADERS)))),
             constraints=EnsureStr(),  # TODO: EnsureURL
             metavar='url',
             nargs='+'),
@@ -129,7 +129,7 @@ class DownloadURL(Interface):
                          "ds": ds}
 
         got_ds_instance = isinstance(dataset, Dataset)
-        dir_is_target = not path or path.endswith(op.sep)
+        dir_is_target = not path or str(path).endswith(op.sep)
         path = str(resolve_path(path or op.curdir, ds=dataset))
         if dir_is_target:
             # resolve_path() doesn't preserve trailing separators. Add one for
@@ -269,7 +269,7 @@ URLs:
                                 options=['--relaxed'])
                         except CommandError as exc:
                             lgr.warning("Registering %s with %s failed: %s",
-                                        path, url, exc_str(exc))
+                                        path, url, CapturedException(exc))
 
                     if archive:
                         from datalad.api import add_archive_content
