@@ -11,6 +11,7 @@
 __docformat__ = 'restructuredtext'
 
 
+from copy import copy
 import logging
 from functools import partial
 from itertools import dropwhile
@@ -19,11 +20,11 @@ import os.path as op
 import re
 import sys
 
-from datalad.dochelpers import exc_str
 from datalad.interface.base import Interface
 from datalad.interface.utils import eval_results
 from datalad.interface.base import build_doc
 from datalad.interface.results import get_status_dict
+from datalad.core.local.run import assume_ready_opt
 from datalad.core.local.run import run_command
 from datalad.core.local.run import format_command
 from datalad.core.local.run import _format_cmd_shorty
@@ -33,6 +34,7 @@ from datalad.consts import PRE_INIT_COMMIT_SHA
 from datalad.support.constraints import EnsureNone, EnsureStr
 from datalad.support.param import Parameter
 from datalad.support.json_py import load_stream
+from datalad.support.exceptions import CapturedException
 
 from datalad.distribution.dataset import require_dataset
 from datalad.distribution.dataset import EnsureDataset
@@ -40,6 +42,11 @@ from datalad.distribution.dataset import datasetmethod
 
 lgr = logging.getLogger('datalad.interface.rerun')
 
+rerun_assume_ready_opt = copy(assume_ready_opt)
+rerun_assume_ready_opt._doc += """
+Note that this option also affects any additional outputs that are
+automatically inferred based on inspecting changed files in the run commit."""
+
 
 @build_doc
 class Rerun(Interface):
@@ -144,6 +151,7 @@ class Rerun(Interface):
             doc="""Don't actually re-execute anything, just display what would
             be done. [CMD: Note: If you give this option, you most likely want
             to set --output-format to 'json' or 'json_pp'. CMD]"""),
+        assume_ready=rerun_assume_ready_opt,
         explicit=Parameter(
             args=("--explicit",),
             action="store_true",
@@ -189,6 +197,7 @@ class Rerun(Interface):
             onto=None,
             script=None,
             report=False,
+            assume_ready=None,
             explicit=False):
 
         ds = require_dataset(
@@ -252,7 +261,8 @@ class Rerun(Interface):
         elif report:
             handler = _report
         else:
-            handler = partial(_rerun, explicit=explicit)
+            handler = partial(_rerun, assume_ready=assume_ready,
+                              explicit=explicit)
 
         for res in handler(ds, results):
             yield res
@@ -278,7 +288,7 @@ def _revrange_as_results(dset, revrange):
         except ValueError as exc:
             # Recast the error so the message includes the revision.
             raise ValueError(
-                "Error on {}'s message: {}".format(rev, exc_str(exc)))
+                "Error on {}'s message".format(rev)) from exc
 
         if info is not None:
             if len(parents) != 1:
@@ -303,7 +313,9 @@ def _rerun_as_results(dset, revrange, since, branch, onto, message):
     try:
         results = _revrange_as_results(dset, revrange)
     except ValueError as exc:
-        yield get_status_dict("run", status="error", message=exc_str(exc))
+        ce = CapturedException(exc)
+        yield get_status_dict("run", status="error", message=str(ce),
+                              exception=ce)
         return
 
     ds_repo = dset.repo
@@ -372,7 +384,7 @@ def _mark_nonrun_result(result, which):
     return result
 
 
-def _rerun(dset, results, explicit=False):
+def _rerun(dset, results, assume_ready=None, explicit=False):
     ds_repo = dset.repo
     # Keep a map from an original hexsha to a new hexsha created by the rerun
     # (i.e. a reran, cherry-picked, or merged commit).
@@ -495,6 +507,7 @@ def _rerun(dset, results, explicit=False):
                                  inputs=run_info.get("inputs", []),
                                  extra_inputs=run_info.get("extra_inputs", []),
                                  outputs=outputs,
+                                 assume_ready=assume_ready,
                                  explicit=explicit,
                                  rerun_outputs=auto_outputs,
                                  message=message,
@@ -639,9 +652,8 @@ def get_run_info(dset, message):
         runinfo = json.loads(runinfo)
     except Exception as e:
         raise ValueError(
-            'cannot rerun command, command specification is not valid JSON: '
-            '%s' % exc_str(e)
-        )
+            'cannot rerun command, command specification is not valid JSON'
+        ) from e
     if not isinstance(runinfo, (list, dict)):
         # this is a run record ID -> load the beast
         record_dir = dset.config.get(
