@@ -13,16 +13,31 @@
 __docformat__ = 'restructuredtext'
 
 import os
+from glob import glob
 from os import unlink
 from os.path import (
     basename,
     exists,
-    join as opj,
+)
+from os.path import join as opj
+from os.path import (
     lexists,
     pardir,
 )
-from glob import glob
 
+from datalad.api import (
+    add_archive_content,
+    clean,
+)
+from datalad.consts import (
+    ARCHIVES_SPECIAL_REMOTE,
+    DATALAD_SPECIAL_REMOTES_UUIDS,
+)
+from datalad.support.annexrepo import AnnexRepo
+from datalad.support.exceptions import (
+    CommandError,
+    FileNotInRepositoryError,
+)
 from datalad.tests.utils import (
     assert_cwd_unchanged,
     assert_equal,
@@ -43,18 +58,10 @@ from datalad.tests.utils import (
     ok_file_has_content,
     ok_file_under_git,
     serve_path_via_http,
-    slow,
-    swallow_logs,
     swallow_outputs,
     with_tempfile,
     with_tree,
 )
-
-from datalad.support.annexrepo import AnnexRepo
-from datalad.support.exceptions import (
-    CommandError,
-    FileNotInRepositoryError,
-)
 from datalad.utils import (
     chpwd,
     find_files,
@@ -62,15 +69,6 @@ from datalad.utils import (
     on_windows,
     rmtemp,
 )
-from datalad.api import (
-    add_archive_content,
-    clean,
-)
-from datalad.consts import (
-    ARCHIVES_SPECIAL_REMOTE,
-    DATALAD_SPECIAL_REMOTES_UUIDS,
-)
-
 
 treeargs = dict(
     tree=(
@@ -491,9 +489,8 @@ class TestAddArchiveOptions():
 
         # previous state of things:
         prev_files = list(find_files('.*', self.annex.path))
-        with assert_raises(Exception), \
-                swallow_logs():
-            self.annex.whereis(key1, key=True, output='full')
+        assert_equal(self.annex.whereis(key1, key=True, output='full'), {})
+
         commits_prior = list(self.annex.get_branch_commits_('git-annex'))
         add_archive_content('1.tar', annex=self.annex, strip_leading_dirs=True, delete_after=True)
         commits_after = list(self.annex.get_branch_commits_('git-annex'))
@@ -566,7 +563,7 @@ class TestAddArchiveOptions():
 
     def assert_no_trash_left_behind(self):
         assert_equal(
-            list(find_files('\.datalad..*', self.annex.path, dirs=True)),
+            list(find_files(r'\.datalad..*', self.annex.path, dirs=True)),
             []
         )
 
