@@ -12,6 +12,7 @@
 
 __docformat__ = 'restructuredtext'
 
+import json
 import os.path as op
 import sys
 from unittest.mock import patch
@@ -39,7 +40,6 @@ from datalad.tests.utils import (
     ok_file_has_content,
     on_windows,
     patch_config,
-    skip_if,
     with_tempfile,
     with_tree,
 )
@@ -49,7 +49,6 @@ from datalad.support.exceptions import (
     InsufficientArgumentsError,
 )
 from datalad.api import run_procedure
-from datalad import cfg as dl_cfg
 
 
 @with_tempfile(mkdir=True)
@@ -79,7 +78,6 @@ def test_dirty(path):
     assert_repo_status(ds.path)
 
 
-@skip_if(cond=on_windows and dl_cfg.obtain("datalad.repo.version") < 6)
 @with_tree(tree={
     'code': {'datalad_test_proc.py': """\
 import sys
@@ -211,7 +209,6 @@ def _check_procedure_properties(ps):
         len(ps))
 
 
-@skip_if(cond=on_windows and dl_cfg.obtain("datalad.repo.version") < 6)
 @with_tree(tree={
     'code': {'datalad_test_proc.py': """\
 import sys
@@ -405,15 +402,17 @@ def test_name_with_underscore(path):
     # environment variable.
     with patch.dict("os.environ",
                     {"DATALAD_PROCEDURES_PRINT_ARGS_CALL__FORMAT":
-                     'python {script}'}):
+                     '%s {script}' % sys.executable}):
         with assert_raises(ValueError):
             ds.run_procedure(spec=["print_args"])
 
     # But it can be set via DATALAD_CONFIG_OVERRIDES_JSON.
     with patch.dict("os.environ",
                     {"DATALAD_CONFIG_OVERRIDES_JSON":
-                     '{"datalad.procedures.print_args.call-format": '
-                     '"python {script}"}'}):
+                     json.dumps({
+                         "datalad.procedures.print_args.call-format":
+                         "%s {script}" % sys.executable
+                    })}):
         ds.config.reload()
         ds.run_procedure(spec=["print_args"])
 
