@@ -14,6 +14,7 @@ __docformat__ = 'restructuredtext'
 
 import inspect
 import logging
+import os
 import wrapt
 import sys
 import re
@@ -41,12 +42,12 @@ from datalad.utils import (
     get_wrapped_class,
 )
 from datalad.support.gitrepo import GitRepo
-from datalad.support.exceptions import IncompleteResultsError
-from datalad import cfg as dlcfg
-from datalad.dochelpers import (
-    exc_str,
-    single_or_plural,
+from datalad.support.exceptions import (
+    CapturedException,
+    IncompleteResultsError,
 )
+from datalad import cfg as dlcfg
+from datalad.dochelpers import single_or_plural
 
 from datalad.ui import ui
 import datalad.support.ansi_colors as ac
@@ -62,7 +63,6 @@ from datalad.core.local.resulthooks import (
     run_jsonhook,
 )
 
-
 lgr = logging.getLogger('datalad.interface.utils')
 
 
@@ -171,7 +171,7 @@ def path_is_under(values, path=None):
         # need to protect against unsupported use of relpath() with
         # abspaths on windows from different drives (gh-3724)
         if path_drive != p_drive:
-        # different drives, enough evidence for "not under"
+            # different drives, enough evidence for "not under"
             continue
         rpath = relpath(p, start=path)
         if rpath == curdir \
@@ -230,7 +230,7 @@ def discover_dataset_trace_to_targets(basepath, targetpaths, current_trace,
         current_trace = current_trace + [basepath]
     # this edge is not done, we need to try to reach any downstream
     # dataset
-    undiscovered_ds = set(t for t in targetpaths) # if t != basepath)
+    undiscovered_ds = set(t for t in targetpaths)  # if t != basepath)
     # whether anything in this directory matched a targetpath
     filematch = False
     if isdir(basepath):
@@ -258,8 +258,8 @@ def discover_dataset_trace_to_targets(basepath, targetpaths, current_trace,
                     downward_targets))
     undiscovered_ds = [t for t in undiscovered_ds
                        if includeds and
-                          path_is_subpath(t, current_trace[-1]) and
-                          t in includeds]
+                       path_is_subpath(t, current_trace[-1]) and
+                       t in includeds]
     if filematch or basepath in targetpaths or undiscovered_ds:
         for i, p in enumerate(current_trace[:-1]):
             # TODO RF prepare proper annotated path dicts
@@ -362,7 +362,7 @@ def eval_results(func):
         if not result_renderer:
             result_renderer = dlcfg.get('datalad.api.result-renderer', None)
         # look for potential override of logging behavior
-        result_log_level = dlcfg.get('datalad.log.result-level', None)
+        result_log_level = dlcfg.get('datalad.log.result-level', 'debug')
 
         # query cfg for defaults
         # .is_installed and .config can be costly, so ensure we do
@@ -387,7 +387,10 @@ def eval_results(func):
             # of the command execution
             results = []
             do_custom_result_summary = result_renderer in ('tailored', 'default') \
-                and hasattr(wrapped_class, 'custom_result_summary_renderer')
+                                       and hasattr(wrapped_class, 'custom_result_summary_renderer')
+            pass_summary = do_custom_result_summary and \
+                           getattr(wrapped_class,
+                                   'custom_result_summary_renderer_pass_summary', None)
 
             # process main results
             for r in _process_results(
@@ -443,17 +446,16 @@ def eval_results(func):
             # result summary before a potential exception
             # custom first
             if do_custom_result_summary:
-                wrapped_class.custom_result_summary_renderer(results)
+                if pass_summary:
+                    summary_args = (results, action_summary)
+                else:
+                    summary_args = (results,)
+                wrapped_class.custom_result_summary_renderer(*summary_args)
             elif result_renderer == 'default' and action_summary and \
                     sum(sum(s.values()) for s in action_summary.values()) > 1:
                 # give a summary in default mode, when there was more than one
                 # action performed
-                ui.message("action summary:\n  {}".format(
-                    '\n  '.join('{} ({})'.format(
-                        act,
-                        ', '.join('{}: {}'.format(status, action_summary[act][status])
-                                  for status in sorted(action_summary[act])))
-                                for act in sorted(action_summary))))
+                render_action_summary(action_summary)
 
             if incomplete_results:
                 raise IncompleteResultsError(
@@ -472,20 +474,18 @@ def eval_results(func):
                     # unwind generator if there is one, this actually runs
                     # any processing
                     results = list(results)
-                # render summaries
-                if not result_xfm and result_renderer in ('tailored', 'default'):
-                    # cannot render transformed results
-                    if hasattr(wrapped_class, 'custom_result_summary_renderer'):
-                        wrapped_class.custom_result_summary_renderer(results)
                 if return_type == 'item-or-list' and \
                         len(results) < 2:
                     return results[0] if results else None
                 else:
                     return results
+
             lgr.log(2, "Returning return_func from eval_func for %s", wrapped_class)
             return return_func(generator_func)(*args, **kwargs)
 
-    return eval_func(func)
+    ret = eval_func(func)
+    ret._eval_results = True
+    return ret
 
 
 def default_result_renderer(res):
@@ -498,7 +498,7 @@ def default_result_renderer(res):
                 # can happen, e.g., on windows with paths from different
                 # drives. just go with the original path in this case
                 pass
-        ui.message('{action}({status}):{path}{type}{msg}'.format(
+        ui.message('{action}({status}):{path}{type}{msg}{err}'.format(
             action=ac.color_word(
                 res.get('action', '<action-unspecified>'),
                 ac.BOLD),
@@ -511,7 +511,21 @@ def default_result_renderer(res):
                 res['message'][0] % res['message'][1:]
                 if isinstance(res['message'], tuple) else res[
                     'message'])
-            if res.get('message', None) else ''))
+            if res.get('message', None) else '',
+            err=ac.color_word(' [{}]'.format(
+                res['error_message'][0] % res['error_message'][1:]
+                if isinstance(res['error_message'], tuple) else res[
+                    'error_message']), ac.RED)
+            if res.get('error_message', None) and res.get('status', None) != 'ok' else ''))
+
+
+def render_action_summary(action_summary):
+    ui.message("action summary:\n  {}".format(
+        '\n  '.join('{} ({})'.format(
+            act,
+            ', '.join('{}: {}'.format(status, action_summary[act][status])
+                      for status in sorted(action_summary[act])))
+                    for act in sorted(action_summary))))
 
 
 def _display_suppressed_message(nsimilar, ndisplayed, last_ts, final=False):
@@ -524,7 +538,7 @@ def _display_suppressed_message(nsimilar, ndisplayed, last_ts, final=False):
         # CPU load than the actual processing
         # arbitrarily go for a 2Hz update frequency -- it "feels" good
         if last_ts is None or final or (ts - last_ts > 0.5):
-            ui.message('  [{} similar {} been suppressed]'
+            ui.message('  [{} similar {} been suppressed; disable with datalad.ui.suppress-similar-results=off]'
                        .format(n_suppressed,
                                single_or_plural("message has",
                                                 "messages have",
@@ -550,13 +564,17 @@ def _process_results(
     # used to track repeated messages in the default renderer
     last_result = None
     last_result_ts = None
-    # which result dict keys to inspect for changes to discover repetions
+    # which result dict keys to inspect for changes to discover repetitions
     # of similar messages
     repetition_keys = set(('action', 'status', 'type', 'refds'))
     # counter for detected repetitions
     result_repetitions = 0
     # how many repetitions to show, before suppression kicks in
-    render_n_repetitions = 10 if sys.stdout.isatty() else float("inf")
+    render_n_repetitions = \
+        dlcfg.obtain('datalad.ui.suppress-similar-results-threshold') \
+            if sys.stdout.isatty() \
+               and dlcfg.obtain('datalad.ui.suppress-similar-results') \
+            else float("inf")
 
     for res in results:
         if not res or 'action' not in res:
@@ -582,7 +600,7 @@ def _process_results(
                 res_lgr = getattr(
                     res_lgr,
                     default_logchannels[res['status']]
-                    if result_log_level is None
+                    if result_log_level == 'match-status'
                     else result_log_level)
             msg = res['message']
             msgargs = None
@@ -604,8 +622,8 @@ def _process_results(
                 except TypeError as exc:
                     raise TypeError(
                         "Failed to render %r with %r from %r: %s"
-                        % (msg, msgargs, res, exc_str(exc))
-                    )
+                        % (msg, msgargs, res, str(exc))
+                    ) from exc
             else:
                 res_lgr(msg)
 
@@ -636,10 +654,10 @@ def _process_results(
         elif result_renderer in ('json', 'json_pp'):
             ui.message(json.dumps(
                 {k: v for k, v in res.items()
-                 if k not in ('message', 'logger')},
+                 if k not in ('logger')},
                 sort_keys=True,
                 indent=2 if result_renderer.endswith('_pp') else None,
-                default=lambda x: str(x)))
+                default=str))
         elif result_renderer in ('tailored', 'default'):
             if hasattr(cmd_class, 'custom_result_renderer'):
                 cmd_class.custom_result_renderer(res, **allkwargs)
@@ -648,7 +666,7 @@ def _process_results(
                 result_renderer(res, **allkwargs)
             except Exception as e:
                 lgr.warning('Result rendering failed for: %s [%s]',
-                            res, exc_str(e))
+                            res, CapturedException(e))
         else:
             raise ValueError('unknown result renderer "{}"'.format(result_renderer))
 
@@ -679,7 +697,7 @@ def keep_result(res, rfilter, **kwargs):
     except ValueError as e:
         # make sure to report the excluded result to massively improve
         # debugging experience
-        lgr.debug('Not reporting result (%s): %s', exc_str(e), res)
+        lgr.debug('Not reporting result (%s): %s', CapturedException(e), res)
         return False
     return True
 
