@@ -23,11 +23,11 @@ from datalad.api import (
 )
 from datalad.utils import (
     chpwd,
-    on_windows,
     Path,
     PurePosixPath,
 )
 from datalad.tests.utils import (
+    assert_true,
     assert_false,
     assert_in,
     assert_not_in,
@@ -286,13 +286,11 @@ def test_get_subdatasets(origpath, path):
 def test_state(path):
     ds = Dataset.create(path)
     sub = ds.create('sub')
-    res = ds.subdatasets()
-    assert_result_count(res, 1, path=sub.path)
-    # by default we are not reporting any state info
-    assert_not_in('state', res[0])
+    assert_result_count(
+        ds.subdatasets(), 1, path=sub.path, state='present')
     # uninstall the subdataset
     ds.uninstall('sub')
-    # normale 'gone' is "absent"
+    # normal 'gone' is "absent"
     assert_false(sub.is_installed())
     assert_result_count(
         ds.subdatasets(), 1, path=sub.path, state='absent')
@@ -327,3 +325,36 @@ def test_parent_on_unborn_branch(path):
     ds.repo.add_submodule(path="sub")
     eq_(ds.subdatasets(result_xfm='relpaths'),
         ["sub"])
+
+
+@with_tempfile
+@with_tempfile
+def test_name_starts_with_hyphen(origpath, path):
+    ds = Dataset.create(origpath)
+    # create
+    dash_sub = ds.create('-sub')
+    assert_true(dash_sub.is_installed())
+    assert_result_count(
+        ds.subdatasets(), 1, path=dash_sub.path, state='present')
+
+    # clone
+    ds_clone = Dataset.create(path)
+    dash_clone = clone(source=dash_sub.path, path=os.path.join(path, '-clone'))
+    ds_clone.save(recursive=True)
+    assert_true(dash_clone.is_installed())
+    assert_result_count(
+        ds_clone.subdatasets(), 1, path=dash_clone.path, state='present')
+
+    # uninstall
+    ds_clone.uninstall('-clone')
+    assert_false(dash_clone.is_installed())
+    assert_result_count(
+        ds_clone.subdatasets(), 1, path=dash_clone.path, state='absent')
+
+    # get
+    ds_clone.get('-clone')
+    assert_true(dash_clone.is_installed())
+    assert_result_count(
+        ds_clone.subdatasets(), 1, path=dash_clone.path, state='present')
+
+    assert_repo_status(ds.path)
