@@ -11,8 +11,10 @@
 from simplejson import dumps
 from datalad.metadata.extractors.datacite import MetadataExtractor
 from datalad.metadata.metadata import _get_metadatarelevant_paths
-from nose.tools import assert_equal
-from datalad.tests.utils import with_tree
+from datalad.tests.utils import (
+    assert_equal,
+    with_tree,
+)
 from datalad.api import create
 
 
