@@ -8,24 +8,27 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Test image extractor"""
 
-from datalad.tests.utils import SkipTest
+from datalad.tests.utils import (
+    assert_in,
+    assert_repo_status,
+    assert_result_count,
+    assert_status,
+    eq_,
+    SkipTest,
+    with_tempfile,
+)
 try:
     from PIL import Image
 except ImportError as exc:
-    from datalad.dochelpers import exc_str
     raise SkipTest(
-       "No PIL module available or it cannot be imported: %s" % exc_str(exc))
+       "No PIL module available or it cannot be imported") from exc
 
 from shutil import copy
-from os.path import dirname
-from os.path import join as opj
+from os.path import (
+    dirname,
+    join as opj,
+)
 from datalad.api import Dataset
-from datalad.tests.utils import with_tempfile
-from datalad.tests.utils import ok_clean_git
-from datalad.tests.utils import assert_status
-from datalad.tests.utils import assert_result_count
-from datalad.tests.utils import eq_
-from datalad.tests.utils import assert_in
 
 
 target = {
@@ -45,7 +48,7 @@ def test_image(path):
         opj(dirname(dirname(dirname(__file__))), 'tests', 'data', 'exif.jpg'),
         path)
     ds.save()
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     res = ds.aggregate_metadata()
     assert_status('ok', res)
     res = ds.metadata('exif.jpg')
