@@ -5,9 +5,9 @@ Support functionality for using DueCredit
 """
 
 # Note Text was added/exposed only since DueCredit 0.6.5
-from .due import due, Doi, Url, Text
+from .due import due, Doi, Text
 from ..utils import never_fail, swallow_logs
-from ..dochelpers import exc_str
+from datalad.support.exceptions import CapturedException
 
 import logging
 lgr = logging.getLogger('datalad.duecredit')
@@ -62,7 +62,7 @@ def duecredit_dataset(dataset):
     except Exception as exc:
         lgr.debug(
             "Failed to obtain metadata for %s. Will not provide duecredit entry: %s",
-            dataset, exc_str(exc)
+            dataset, CapturedException(exc)
         )
         return
 
@@ -118,4 +118,4 @@ def duecredit_dataset(dataset):
             version=version,
             description=desc
         )
-        return  # we are done. TODO: should we continue? ;)
\ No newline at end of file
+        return  # we are done. TODO: should we continue? ;)
