@@ -15,12 +15,14 @@ from os import linesep
 from distutils.version import LooseVersion
 from itertools import chain
 
-from datalad.dochelpers import exc_str
 from datalad.log import lgr
 # import version helper from config to have only one implementation
 # config needs this to avoid circular imports
 from datalad.config import get_git_version as __get_git_version
-from .exceptions import CommandError
+from .exceptions import (
+    CapturedException,
+    CommandError,
+)
 
 __all__ = ['UnknownVersion', 'ExternalVersions', 'external_versions']
 
@@ -152,6 +154,11 @@ class ExternalVersions(object):
         'cmd:system-ssh': _get_system_ssh_version,
         'cmd:7z': _get_system_7z_version,
     }
+    # ad-hoc hardcoded map for relevant Python packages which do not provide
+    # __version__ and are shipped by a differently named pypi package
+    _PYTHON_PACKAGES = {  # Python package -> distribution package
+        'github': 'pygithub',
+    }
     _INTERESTING = (
         'annexremote',
         'appdirs',
@@ -189,9 +196,10 @@ class ExternalVersions(object):
 
         # try pkg_resources
         if version is None and hasattr(value, '__name__'):
+            pkg_name = klass._PYTHON_PACKAGES.get(value.__name__, value.__name__)
             try:
                 import pkg_resources
-                version = pkg_resources.get_distribution(value.__name__).version
+                version = pkg_resources.get_distribution(pkg_name).version
             except Exception:
                 pass
 
@@ -237,7 +245,7 @@ class ExternalVersions(object):
                     version = self._deduce_version(version)
                 except Exception as exc:
                     lgr.debug("Failed to deduce version of %s due to %s"
-                              % (modname, exc_str(exc)))
+                              % (modname, CapturedException(exc)))
                     return None
             else:
                 if module is None:
@@ -249,7 +257,7 @@ class ExternalVersions(object):
                             return None
                         except Exception as exc:
                             lgr.warning("Failed to import module %s due to %s",
-                                        modname, exc_str(exc))
+                                        modname, CapturedException(exc))
                             return None
                     else:
                         module = sys.modules[modname]
