@@ -94,7 +94,7 @@ def split_ext(filename):
 
     Examples
     --------
-    >>> from datalad.plugin.addurls import split_ext
+    >>> from datalad.local.addurls import split_ext
     >>> split_ext("filename.py")
     ('filename', '.py')
 
