@@ -415,7 +415,7 @@ def test_AnnexRepo_web_remote(sitepath, siteurl, dst):
     assert_equal(lfull[WEB_SPECIAL_REMOTE_UUID]['description'], 'web')
 
     # --all and --key are incompatible
-    assert_raises(CommandError, ar.whereis, [], options='--all', output='full', key=True)
+    assert_raises(CommandError, ar.whereis, [testfile], options='--all', output='full', key=True)
 
     # output='descriptions'
     ldesc = ar.whereis(testfile, output='descriptions')
@@ -928,7 +928,7 @@ def test_AnnexRepo_get(src, dst):
 
     annex.drop(testfile)
     with patch.object(GitWitlessRunner, 'run_on_filelist_chunks',
-                      side_effect=check_run, auto_spec=True), \
+                      side_effect=check_run), \
             swallow_outputs():
         annex.get(testfile, jobs=5)
     eq_(called, ['find', 'get'])
@@ -1586,7 +1586,6 @@ def test_annex_add_no_dotfiles(path):
 def test_annex_version_handling_at_min_version(path):
     with set_annex_version(AnnexRepo.GIT_ANNEX_MIN_VERSION):
         po = patch.object(AnnexRepo, '_check_git_annex_version',
-                          auto_spec=True,
                           side_effect=AnnexRepo._check_git_annex_version)
         with po as cmpc:
             eq_(AnnexRepo.git_annex_version, None)
@@ -2567,13 +2566,29 @@ def test_whereis_batch_eqv(path):
     repo_b.drop(["baz"], options=["--from=" + DEFAULT_REMOTE, "--force"])
 
     files = ["foo", "bar", "baz"]
+    keys = repo_b.get_file_key(files)
     for output in "full", "uuids", "descriptions":
-        assert_equal(repo_b.whereis(files=files, batch=False, output=output),
+        out_non_batch = repo_b.whereis(files=files, batch=False, output=output)
+        assert_equal(out_non_batch,
                      repo_b.whereis(files=files, batch=True, output=output))
+        out_non_batch_keys = repo_b.whereis(files=keys, batch=False, key=True, output=output)
+        # should be identical
+        if output == 'full':
+            # we need to map files to keys though
+            assert_equal(out_non_batch_keys,
+                         {k: out_non_batch[f] for f, k in zip(files, keys)})
+        else:
+            assert_equal(out_non_batch, out_non_batch_keys)
 
-    # --key= and --batch are incompatible.
-    with assert_raises(ValueError):
-        repo_b.whereis(files=files, batch=True, key=True)
+        if external_versions['cmd:annex'] >= '8.20210903':
+            # --batch-keys support was introduced
+            assert_equal(out_non_batch_keys,
+                         repo_b.whereis(files=keys, batch=True, key=True, output=output))
+
+    if external_versions['cmd:annex'] < '8.20210903':
+        # --key= and --batch are incompatible.
+        with assert_raises(ValueError):
+            repo_b.whereis(files=files, batch=True, key=True)
 
 
 def test_done_deprecation():
