@@ -48,7 +48,7 @@ def test_get_content_info(path):
 
     # verify general rules on fused info records that are incrementally
     # assembled: for git content info, amended with annex info on 'HEAD'
-    # (to get the last commited stage and with it possibly vanished
+    # (to get the last committed stage and with it possibly vanished
     # content), and lastly annex info wrt to the present worktree, to
     # also get info on added/staged content
     # this fuses the info reported from
@@ -71,7 +71,7 @@ def test_get_content_info(path):
                 r.get('gitshasum', None) and not f.match('subds*'):
             # this should be known to annex, one way or another
             # regardless of whether things add deleted or staged
-            # or anything inbetween
+            # or anything in between
             assert_in('key', r, f)
             assert_in('keyname', r, f)
             assert_in('backend', r, f)
@@ -280,3 +280,35 @@ def test_get_content_info_dotgit(path):
     # Files in .git/ won't be reported, though this takes a kludge on our side
     # before Git 2.25.
     assert_false(ds.repo.get_content_info(paths=[op.join(".git", "config")]))
+
+
+@with_tempfile
+def test_get_content_info_paths_empty_list(path):
+    ds = Dataset(path).create()
+
+    # Unlike None, passing any empty list as paths to get_content_info() does
+    # not report on all content.
+    assert_false(ds.repo.get_content_info(paths=[]))
+    assert_false(ds.repo.get_content_info(paths=[], ref="HEAD"))
+
+    # Add annex content to make sure its not reported.
+    (ds.pathobj / "foo").write_text("foo")
+    ds.save()
+
+    # Same for get_content_annexinfo()...
+    assert_false(ds.repo.get_content_annexinfo(paths=[]))
+    assert_false(ds.repo.get_content_annexinfo(paths=[], init=None))
+    assert_false(ds.repo.get_content_annexinfo(paths=[], ref="HEAD"))
+    assert_false(
+        ds.repo.get_content_annexinfo(paths=[], ref="HEAD", init=None))
+    # ... where whatever was passed for init will be returned as is.
+    assert_equal(
+        ds.repo.get_content_annexinfo(
+            paths=[], ref="HEAD", init={"random": {"entry": "a"}}),
+        {"random": {"entry": "a"}})
+
+
+@with_tempfile
+def test_status_paths_empty_list(path):
+    ds = Dataset(path).create()
+    assert_equal(ds.repo.status(paths=[]), {})
