@@ -11,27 +11,26 @@
 import inspect
 import logging
 import os.path
-from os.path import exists
-
 from logging import makeLogRecord
-
+from os.path import exists
 from unittest.mock import patch
 
+from datalad import cfg as dl_cfg
 from datalad.log import (
     ColorFormatter,
     LoggerHelper,
-    log_progress,
     TraceBack,
+    log_progress,
     with_progress,
     with_result_progress,
 )
-from datalad import cfg as dl_cfg
-from datalad.support.constraints import EnsureBool
 from datalad.support import ansi_colors as colors
-
+from datalad.support.constraints import EnsureBool
 from datalad.tests.utils import (
+    SkipTest,
     assert_equal,
     assert_in,
+    assert_no_open_files,
     assert_not_in,
     assert_re_in,
     known_failure_githubci_win,
@@ -40,7 +39,6 @@ from datalad.tests.utils import (
     ok_generator,
     swallow_logs,
     with_tempfile,
-    SkipTest,
 )
 from datalad.utils import on_windows
 
@@ -68,16 +66,25 @@ def test_logging_to_a_file(dst):
     # do not want to rely on not having race conditions around date/time changes
     # so matching just with regexp
     # (...)? is added to swallow possible traceback logs
-    regex = "\[ERROR\]"
+    regex = r"\[ERROR\]"
     if EnsureBool()(dl_cfg.get('datalad.log.timestamp', False)):
-        regex = "\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2},\d{3} " + regex
+        regex = r"\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2},\d{3} " + regex
     if EnsureBool()(dl_cfg.get('datalad.log.vmem', False)):
-        regex += ' RSS/VMS: \S+/\S+( \S+)?\s*'
-    regex += "(\s+\S+\s*)? " + msg
+        regex += r' RSS/VMS: \S+/\S+( \S+)?\s*'
+    regex += r"(\s+\S+\s*)? " + msg
     assert_re_in(regex, line, match=True)
+
+    # Python's logger is ok (although not documented as supported) to accept
+    # non-string messages, which could be str()'ed.  We should not puke
+    msg2 = "Kenny is alive"
+    lgr.error(RuntimeError(msg2))
+    with open(dst) as f:
+        assert_in(msg2, f.read())
+
     # Close all handlers so windows is happy -- apparently not closed fast enough
     for handler in lgr.handlers:
         handler.close()
+    assert_no_open_files(dst)
 
 
 @with_tempfile
@@ -122,7 +129,7 @@ def check_filters(name):
         lgr3.info('log3')
         assert_in('log1', cml.out)
         assert_in('log2', cml.out)
-        assert 'log3' not in cml.out
+        assert_not_in('log3', cml.out)
 
 
 def test_filters():
@@ -140,7 +147,11 @@ def test_filters():
 
 
 def test_traceback():
-    from inspect import currentframe, getframeinfo
+    from inspect import (
+        currentframe,
+        getframeinfo,
+    )
+
     # do not move lines below among themselves -- we rely on consistent line numbers ;)
     tb_line = getframeinfo(currentframe()).lineno + 2
     def rec(tb, n):
@@ -232,4 +243,4 @@ def test_with_progress_generator():
     # progress iterative over it
     g = with_progress(range(3))
     ok_generator(g)
-    assert_equal(list(g), list(range(3)))
\ No newline at end of file
+    assert_equal(list(g), list(range(3)))
