@@ -44,6 +44,7 @@ from datalad.tests.utils import (
     get_most_obscure_supported_name,
     ignore_nose_capturing_stdout,
     known_failure_githubci_win,
+    known_failure_windows,
     local_testrepo_flavors,
     nok_startswith,
     OBSCURE_FILENAMES,
@@ -219,14 +220,13 @@ def test_with_tempfile_specified_prefix(d1):
     ok_('test_with_tempfile_specified_prefix' not in d1)
 
 
-@known_failure_githubci_win
 def test_get_most_obscure_supported_name():
     n = get_most_obscure_supported_name()
-    if platform.system() in ('Linux', 'Darwin'):
-        eq_(n, OBSCURE_PREFIX + OBSCURE_FILENAMES[1])
-    else:
-        # ATM no one else is as good
-        ok_(n in OBSCURE_PREFIX + OBSCURE_FILENAMES[2:])
+    ok_startswith(n, OBSCURE_PREFIX)
+    ok_(len(OBSCURE_FILENAMES) > 1)
+    # from more complex to simpler ones
+    ok_(len(OBSCURE_FILENAMES[0]) > len(OBSCURE_FILENAMES[-1]))
+    print(repr(n))
 
 
 def test_keeptemp_via_env_variable():
@@ -438,7 +438,7 @@ def _test_serve_path_via_http(test_fpath, tmp_dir):  # pragma: no cover
 
 
 # just look at the path specs...
-@known_failure_githubci_win
+@known_failure_windows
 def test_serve_path_via_http():
     for test_fpath in ['test1.txt',
                        'test_dir/test2.txt',
@@ -622,7 +622,7 @@ def test_testsui():
 def test_setup():
     # just verify that we monkey patched consts correctly
     from datalad.consts import DATASETS_TOPURL
-    eq_(DATASETS_TOPURL, 'http://datasets-tests.datalad.org/')
+    eq_(DATASETS_TOPURL, 'https://datasets-tests.datalad.org/')
     from datalad.tests.utils import get_datasets_topdir
     eq_(get_datasets_topdir(), 'datasets-tests.datalad.org')
 
