@@ -90,7 +90,7 @@ from ..support.external_versions import external_versions
 from ..support.vcr_ import *
 from ..support.keyring_ import MemoryKeyring
 from ..support.network import RI
-from ..dochelpers import exc_str, borrowkwargs
+from ..dochelpers import borrowkwargs
 from ..cmdline.helpers import get_repo_instance
 from ..consts import (
     ARCHIVES_TEMP_DIR,
@@ -135,7 +135,7 @@ def skip_if_no_module(module):
     try:
         imp = __import__(module)
     except Exception as exc:
-        raise SkipTest("Module %s fails to load: %s" % (module, exc_str(exc)))
+        raise SkipTest("Module %s fails to load" % module) from exc
 
 
 def skip_if_scrapy_without_selector():
@@ -303,31 +303,6 @@ def skip_nomultiplex_ssh(func):
         return func(*args, **kwargs)
     return  _wrap_skip_nomultiplex_ssh
 
-
-@optional_args
-def skip_v6_or_later(func, method='raise'):
-    """Skip tests if v6 or later will be used as the default repo version.
-
-    The default repository version is controlled by the configured value of
-    DATALAD_REPO_VERSION and whether v5 repositories are supported by the
-    installed git-annex.
-    """
-
-    from datalad.support.annexrepo import AnnexRepo
-
-    version = dl_cfg.obtain("datalad.repo.version")
-    info = AnnexRepo.check_repository_versions()
-
-    @skip_if(version >= 6 or 5 not in info["supported"],
-             msg="Skip test in v6+ test run", method=method)
-    @wraps(func)
-    @attr('skip_v6_or_later')
-    @attr('v6_or_later')
-    def  _wrap_skip_v6_or_later(*args, **kwargs):
-        return func(*args, **kwargs)
-    return  _wrap_skip_v6_or_later
-
-
 #
 # Addition "checkers"
 #
@@ -424,7 +399,7 @@ def _prep_file_under_git(path, filename):
     # do absolute() in addition to always get an absolute path
     # even with non-existing paths on windows
     path = str(Path(path).resolve().absolute())  # intentional realpath to match GitRepo behavior
-    file_repo_dir = op.relpath(path, repo.path)
+    file_repo_dir = relpath(path, repo.path)
     file_repo_path = filename if file_repo_dir == curdir else opj(file_repo_dir, filename)
     return annex, file_repo_path, filename, path, repo
 
@@ -829,39 +804,6 @@ def known_failure(func):
     return  _wrap_known_failure
 
 
-def known_failure_v6_or_later(func):
-    """Test decorator marking a test as known to fail in a v6+ test run
-
-    If the default repository version is 6 or later behaves like `known_failure`.
-    Otherwise the original (undecorated) function is returned.
-    The default repository version is controlled by the configured value of
-    DATALAD_REPO_VERSION and whether v5 repositories are supported by the
-    installed git-annex.
-    """
-
-    from datalad.support.annexrepo import AnnexRepo
-
-    version = dl_cfg.obtain("datalad.repo.version")
-    info = AnnexRepo.check_repository_versions()
-
-    if (version and version >= 6) or 5 not in info["supported"]:
-
-        @known_failure
-        @wraps(func)
-        @attr('known_failure_v6_or_later')
-        @attr('v6_or_later')
-        def v6_func(*args, **kwargs):
-            return func(*args, **kwargs)
-
-        return v6_func
-
-    return func
-
-
-# TODO: Remove once the released version of datalad-crawler no longer uses it.
-known_failure_v6 = known_failure_v6_or_later
-
-
 def known_failure_direct_mode(func):
     """DEPRECATED.  Stop using.  Does nothing
 
@@ -901,20 +843,6 @@ def known_failure_windows(func):
     return func
 
 
-def known_failure_appveyor(func):
-    """Test decorator marking a test as known to fail on AppVeyor.
-    """
-    if 'APPVEYOR' in os.environ:
-        @known_failure
-        @wraps(func)
-        @attr('known_failure_appveyor')
-        @attr('appveyor')
-        def dm_func(*args, **kwargs):
-            return func(*args, **kwargs)
-        return dm_func
-    return func
-
-
 def known_failure_githubci_win(func):
     """Test decorator for a known test failure on Github's Windows CI
     """
@@ -1005,7 +933,7 @@ def _get_testrepos_uris(regex, flavors):
         _nested_submodule_annex_test_repo = NestedDataset()
         _inner_submodule_annex_test_repo = InnerSubmodule()
         _TESTREPOS = {'basic_annex':
-                        {'network': 'git://github.com/datalad/testrepo--basic--r1',
+                        {'network': 'https://github.com/datalad/testrepo--basic--r1',
                          'local': _basic_annex_test_repo.path,
                          'local-url': _basic_annex_test_repo.url},
                       'basic_git':
@@ -1088,8 +1016,8 @@ def with_testrepos(t, regex='.*', flavors='auto', skip=False, count=None):
     def  _wrap_with_testrepos(*arg, **kw):
         # addurls with our generated file:// URLs doesn't work on appveyor
         # https://ci.appveyor.com/project/mih/datalad/builds/29841505/job/330rwn2a3cvtrakj
-        if 'APPVEYOR' in os.environ:
-            raise SkipTest("Testrepo setup is broken on AppVeyor")
+        #if 'APPVEYOR' in os.environ:
+        #    raise SkipTest("Testrepo setup is broken on AppVeyor")
         # TODO: would need to either avoid this "decorator" approach for
         # parametric tests or again aggregate failures like sweepargs does
         flavors_ = _get_resolved_flavors(flavors)
@@ -1167,14 +1095,7 @@ def with_sameas_remote(func, autoenabled=False):
         if autoenabled:
             options.append("autoenable=true")
         options.append("--sameas=r_dir")
-
-        try:
-            repo.init_remote("r_rsync", options=options)
-        except CommandError:
-            if repo.git_annex_version < "7.20191017":
-                raise SkipTest("git-annex lacks --sameas support")
-            # This should have --sameas support.
-            raise
+        repo.init_remote("r_rsync", options=options)
         return func(*(fn_args + (repo,)), **kwargs)
     return  _wrap_with_sameas_remote
 
@@ -1425,7 +1346,7 @@ def assert_result_values_equal(results, prop, values):
 
 def assert_result_values_cond(results, prop, cond):
     """Verify that the values of all results for a given key in the status dicts
-    fullfill condition `cond`.
+    fulfill condition `cond`.
 
     Parameters
     ----------
@@ -1706,12 +1627,12 @@ def assert_repo_status(path, annex=None, untracked_mode='normal', **kwargs):
 def get_convoluted_situation(path, repocls=AnnexRepo):
     from datalad.api import create
 
-    if 'APPVEYOR' in os.environ:
-        # issue only happens on appveyor, Python itself implodes
-        # cannot be reproduced on a real windows box
-        raise SkipTest(
-            'get_convoluted_situation() causes appveyor to crash, '
-            'reason unknown')
+    #if 'APPVEYOR' in os.environ:
+    #    # issue only happens on appveyor, Python itself implodes
+    #    # cannot be reproduced on a real windows box
+    #    raise SkipTest(
+    #        'get_convoluted_situation() causes appveyor to crash, '
+    #        'reason unknown')
     repo = repocls(path, create=True)
     # use create(force) to get an ID and config into the empty repo
     ds = Dataset(path).create(force=True)
@@ -1761,26 +1682,26 @@ def get_convoluted_situation(path, repocls=AnnexRepo):
         ds.save(to_git=True)
         ds.drop([
             'file_dropped_clean',
-            op.join('subdir', 'file_dropped_clean')],
+            opj('subdir', 'file_dropped_clean')],
             check=False)
     # clean and proper subdatasets
     ds.create('subds_clean')
-    ds.create(op.join('subdir', 'subds_clean'))
+    ds.create(opj('subdir', 'subds_clean'))
     ds.create('subds_unavailable_clean')
-    ds.create(op.join('subdir', 'subds_unavailable_clean'))
+    ds.create(opj('subdir', 'subds_unavailable_clean'))
     # uninstall some subdatasets (still clean)
     ds.uninstall([
         'subds_unavailable_clean',
-        op.join('subdir', 'subds_unavailable_clean')],
+        opj('subdir', 'subds_unavailable_clean')],
         check=False)
     assert_repo_status(ds.path)
     # make a dirty subdataset
     ds.create('subds_modified')
-    ds.create(op.join('subds_modified', 'someds'))
-    ds.create(op.join('subds_modified', 'someds', 'dirtyds'))
+    ds.create(opj('subds_modified', 'someds'))
+    ds.create(opj('subds_modified', 'someds', 'dirtyds'))
     # make a subdataset with additional commits
-    ds.create(op.join('subdir', 'subds_modified'))
-    pdspath = op.join(ds.path, 'subdir', 'subds_modified', 'progressedds')
+    ds.create(opj('subdir', 'subds_modified'))
+    pdspath = opj(ds.path, 'subdir', 'subds_modified', 'progressedds')
     ds.create(pdspath)
     create_tree(
         pdspath,
@@ -1789,10 +1710,10 @@ def get_convoluted_situation(path, repocls=AnnexRepo):
     Dataset(pdspath).save()
     assert_repo_status(pdspath)
     # staged subds, and files
-    create(op.join(ds.path, 'subds_added'))
+    create(opj(ds.path, 'subds_added'))
     ds.repo.add_submodule('subds_added')
-    create(op.join(ds.path, 'subdir', 'subds_added'))
-    ds.repo.add_submodule(op.join('subdir', 'subds_added'))
+    create(opj(ds.path, 'subdir', 'subds_added'))
+    ds.repo.add_submodule(opj('subdir', 'subds_added'))
     # some more untracked files
     create_tree(
         ds.path,
@@ -1815,18 +1736,18 @@ def get_convoluted_situation(path, repocls=AnnexRepo):
             },
         }
     )
-    ds.repo.add(['file_added', op.join('subdir', 'file_added')])
+    ds.repo.add(['file_added', opj('subdir', 'file_added')])
     # untracked subdatasets
-    create(op.join(ds.path, 'subds_untracked'))
-    create(op.join(ds.path, 'subdir', 'subds_untracked'))
+    create(opj(ds.path, 'subds_untracked'))
+    create(opj(ds.path, 'subdir', 'subds_untracked'))
     # deleted files
-    os.remove(op.join(ds.path, 'file_deleted'))
-    os.remove(op.join(ds.path, 'subdir', 'file_deleted'))
+    os.remove(opj(ds.path, 'file_deleted'))
+    os.remove(opj(ds.path, 'subdir', 'file_deleted'))
     # staged deletion
     ds.repo.remove('file_staged_deleted')
     # modified files
     if isinstance(ds.repo, AnnexRepo):
-        ds.repo.unlock(['file_modified', op.join('subdir', 'file_modified')])
+        ds.repo.unlock(['file_modified', opj('subdir', 'file_modified')])
         create_tree(
             ds.path,
             {
@@ -1882,7 +1803,7 @@ def get_deeply_nested_structure(path):
     # a subtree of datasets
     subds = ds.create('subds_modified')
     # another dataset, plus an additional dir in it
-    ds.create(op.join('subds_modified', 'subds_lvl1_modified'))
+    ds.create(opj('subds_modified', 'subds_lvl1_modified'))
     create_tree(
         ds.path,
         {
@@ -1912,15 +1833,15 @@ def get_deeply_nested_structure(path):
     (ds.pathobj / 'link2dir').symlink_to('subdir')
     # upwards pointing symlink to directory within the same dataset
     (ds.pathobj / 'directory_untracked' / 'link2dir').symlink_to(
-        op.join('..', 'subdir'))
+        opj('..', 'subdir'))
     # symlink pointing to a subdataset mount in the same dataset
     (ds.pathobj / 'link2subdsroot').symlink_to('subds_modified')
     # symlink to a dir in a subdataset (across dataset boundaries)
     (ds.pathobj / 'link2subdsdir').symlink_to(
-        op.join('subds_modified', 'subdir'))
+        opj('subds_modified', 'subdir'))
     # symlink to a dir in a superdataset (across dataset boundaries)
     (ut.Path(subds.path) / 'link2superdsdir').symlink_to(
-        op.join('..', 'subdir'))
+        opj('..', 'subdir'))
     return ds
 
 
@@ -1928,11 +1849,8 @@ def maybe_adjust_repo(repo):
     """Put repo into an adjusted branch if it is not already.
     """
     if not repo.is_managed_branch():
-        # The next condition can be removed once GIT_ANNEX_MIN_VERSION is at
-        # least 7.20190912.
-        if not repo.supports_unlocked_pointers:
-            repo.call_annex(["upgrade"])
-            repo.config.reload(force=True)
+        repo.call_annex(["upgrade"])
+        repo.config.reload(force=True)
         repo.adjust()
 
 
